<?php

namespace Restaurant\DeliveryLocation\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Restaurant\DeliveryLocation\Http\Requests\DeliverylocationRequest;
use Restaurant\DeliveryLocation\Interfaces\DeliverylocationRepositoryInterface;
use Restaurant\DeliveryLocation\Models\Deliverylocation;

/**
 * Resource controller class for deliverylocation.
 */
class DeliverylocationResourceController extends BaseController
{

    /**
     * Initialize deliverylocation resource controller.
     *
     * @param type DeliverylocationRepositoryInterface $deliverylocation
     *
     * @return null
     */
    public function __construct(DeliverylocationRepositoryInterface $deliverylocation)
    {
        parent::__construct();
        $this->repository = $deliverylocation;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Restaurant\DeliveryLocation\Repositories\Criteria\DeliverylocationResourceCriteria::class);
    }

    /**
     * Display a list of deliverylocation.
     *
     * @return Response
     */
    public function index(DeliverylocationRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Restaurant\DeliveryLocation\Repositories\Presenter\DeliverylocationPresenter::class)
                ->$function();
        }

        $deliverylocations = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('delivery_location::deliverylocation.names'))
            ->view('delivery_location::deliverylocation.index', true)
            ->data(compact('deliverylocations', 'view'))
            ->output();
    }

    /**
     * Display deliverylocation.
     *
     * @param Request $request
     * @param Model   $deliverylocation
     *
     * @return Response
     */
    public function show(DeliverylocationRequest $request, Deliverylocation $deliverylocation)
    {

        if ($deliverylocation->exists) {
            $view = 'delivery_location::deliverylocation.show';
        } else {
            $view = 'delivery_location::deliverylocation.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('delivery_location::deliverylocation.name'))
            ->data(compact('deliverylocation'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new deliverylocation.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(DeliverylocationRequest $request)
    {

        $deliverylocation = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('delivery_location::deliverylocation.name')) 
            ->view('delivery_location::deliverylocation.create', true) 
            ->data(compact('deliverylocation'))
            ->output();
    }

    /**
     * Create new deliverylocation.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(DeliverylocationRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $deliverylocation                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('delivery_location::deliverylocation.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('delivery_location/deliverylocation/' . $deliverylocation->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/delivery_location/deliverylocation'))
                ->redirect();
        }

    }

    /**
     * Show deliverylocation for editing.
     *
     * @param Request $request
     * @param Model   $deliverylocation
     *
     * @return Response
     */
    public function edit(DeliverylocationRequest $request, Deliverylocation $deliverylocation)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('delivery_location::deliverylocation.name'))
            ->view('delivery_location::deliverylocation.edit', true)
            ->data(compact('deliverylocation'))
            ->output();
    }

    /**
     * Update the deliverylocation.
     *
     * @param Request $request
     * @param Model   $deliverylocation
     *
     * @return Response
     */
    public function update(DeliverylocationRequest $request, Deliverylocation $deliverylocation)
    {
        try {
            $attributes = $request->all();

            $deliverylocation->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('delivery_location::deliverylocation.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('delivery_location/deliverylocation/' . $deliverylocation->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('delivery_location/deliverylocation/' . $deliverylocation->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the deliverylocation.
     *
     * @param Model   $deliverylocation
     *
     * @return Response
     */
    public function destroy(DeliverylocationRequest $request, Deliverylocation $deliverylocation)
    {
        try {

            $deliverylocation->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('delivery_location::deliverylocation.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('delivery_location/deliverylocation/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('delivery_location/deliverylocation/' . $deliverylocation->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple deliverylocation.
     *
     * @param Model   $deliverylocation
     *
     * @return Response
     */
    public function delete(DeliverylocationRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('delivery_location::deliverylocation.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('delivery_location/deliverylocation'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/delivery_location/deliverylocation'))
                ->redirect();
        }

    }

    /**
     * Restore deleted deliverylocations.
     *
     * @param Model   $deliverylocation
     *
     * @return Response
     */
    public function restore(DeliverylocationRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('delivery_location::deliverylocation.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/delivery_location/deliverylocation'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/delivery_location/deliverylocation/'))
                ->redirect();
        }

    }

}
